package turgen.plugin.standard;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import turgen.Turgen;
import turgen.generator.PulseCrate;
import turgen.playlist.AbstractPlayListItem;


/**Playlist item for Standard Plugin*/
public class StandardPlaylistItem extends AbstractPlayListItem {

    public String fname=null;
    public int inputType=0;
    public static final int IT_MONOLITHIC_BINARY=0;
    public static final int IT_BINARY=1;
    public static final int IT_DATA=2;
    public static final int IT_BASIC_TOKENIZED=3;
    public static final int IT_BASIC_SOURCE=4;
    
    private static final String[] methodStrings = {"[mB]","[B]","[D]","[BAS]","[BASsrc]"};
    
    public int conversionFlags;
    public static final int CF_LONGIRG=1;
    public static final int CF_SHORTIRG=2;
    public static final int CF_BOOTBASIC=4;
    

    /** Create new instance*/
    public StandardPlaylistItem(String inF,String outF,String fname,int inputType,int[] silenceList,int flags,PulseCrate pulses) {
        this();
        this.inFile=inF;
        this.outFile=outF;
        this.fname=fname;
        this.inputType=inputType;
        this.silenceList=silenceList;
        this.conversionFlags=flags;
        this.pulses=pulses;
    }

    /**Get string representation*/
    public String toString() {
        if (inputType==IT_BINARY) return methodStrings[inputType]+" "+fname;
        return methodStrings[inputType];
    }

    /** Create blank instance*/
    public StandardPlaylistItem() {
        version = 2;
    }

    /** Validate item
     *@ return Playlist item is Valid
     */
    public boolean validate() {
        if (this.inFile==null) return false;
        if (this.outFile==null) this.outFile="";
        if (this.fname==null) this.fname="NONAME";
        if (this.pulses==null) return false;
        return true;
    }

    
    public AbstractPlayListItem getClonedCopy() {
        int[] pausesCopy = (int[])this.silenceList.clone();
        StandardPlaylistItem item = new StandardPlaylistItem(inFile,outFile,fname,inputType,pausesCopy,conversionFlags,pulses);
        copyBasics(item);
        return item;
    }

    
    public void saveToStream(DataOutputStream dos) throws Exception {
        saveBasics(dos);
        dos.writeUTF(fname);
        dos.writeInt(inputType);
        dos.writeInt(conversionFlags);
    }

    
    public void loadFromStream(DataInputStream dis, int version) throws Exception {
        loadBasics(dis);
        fname=dis.readUTF();
        inputType=dis.readInt();
        if (version<2) {
            boolean shortIRG=dis.readBoolean();
            if (shortIRG==true) {
                conversionFlags |= CF_SHORTIRG;
            }
        }
        else {
            conversionFlags = dis.readInt();
        }
        if (pulses == null) {
            pulses = Turgen.pulseCache.getPulsesForPlugin("turgen.plugin.standard.StandardPlugin")[0];
        }
    }

}
